"""__init__.py"""


from mastapy._internal.dummy_base_class_importer import _DummyBaseClassImport


with _DummyBaseClassImport():
    from ._2532 import BeltDrive
    from ._2533 import BeltDriveType
    from ._2534 import Clutch
    from ._2535 import ClutchHalf
    from ._2536 import ClutchType
    from ._2537 import ConceptCoupling
    from ._2538 import ConceptCouplingHalf
    from ._2539 import Coupling
    from ._2540 import CouplingHalf
    from ._2541 import CrowningSpecification
    from ._2542 import CVT
    from ._2543 import CVTPulley
    from ._2544 import PartToPartShearCoupling
    from ._2545 import PartToPartShearCouplingHalf
    from ._2546 import Pulley
    from ._2547 import RigidConnectorStiffnessType
    from ._2548 import RigidConnectorTiltStiffnessTypes
    from ._2549 import RigidConnectorToothLocation
    from ._2550 import RigidConnectorToothSpacingType
    from ._2551 import RigidConnectorTypes
    from ._2552 import RollingRing
    from ._2553 import RollingRingAssembly
    from ._2554 import ShaftHubConnection
    from ._2555 import SplineLeadRelief
    from ._2556 import SpringDamper
    from ._2557 import SpringDamperHalf
    from ._2558 import Synchroniser
    from ._2559 import SynchroniserCone
    from ._2560 import SynchroniserHalf
    from ._2561 import SynchroniserPart
    from ._2562 import SynchroniserSleeve
    from ._2563 import TorqueConverter
    from ._2564 import TorqueConverterPump
    from ._2565 import TorqueConverterSpeedRatio
    from ._2566 import TorqueConverterTurbine
